@@ -7,12 +7,12 @@ import json
 import time
 import tempfile
 from dask_jobqueue import HTCondorCluster
+from dask_jobqueue.htcondor import HTCondorJob
 from subprocess import check_output, STDOUT
 from jinja2 import Environment, PackageLoader, select_autoescape
 
-from distributed.deploy.spec import ProcessInterface
-from dask.core import Job, Status
-import htcondor
+from distributed.deploy.spec import ProcessInterface, SpecCluster
+from dask_jobqueue.core import Job
 
 
 class Process(ProcessInterface):
@@ -41,6 +41,16 @@ class Process(ProcessInterface):
     def __repr__(self):
         return f"<SSH {type(self).__name__}: status={self.status}>"
 
+from dask_jobqueue.htcondor import HTCondorJob
+
+class Job(HTCondorJob):
+    def __init__(self,*args, **kwargs):
+        super().__init__(*args, **kwargs,
+                        python="source /usr/local/share/root6/bin/thisroot.sh ; /usr/bin/python3"
+                )
+        self.submit_command = "./sched_submit.sh"
+        #self._scheduler = "tcp://90.147.75.109:8989" 
+        self.executable = "/bin/bash"
 
 class Scheduler(Process):
     """A Remote Dask Scheduler controlled via HTCondor
@@ -58,7 +68,7 @@ class Scheduler(Process):
     """
 
     def __init__(
-        self, address: str, connect_options: dict, kwargs: dict, remote_python=None
+        self
     ):
         self.cluster_id = None
         super().__init__()
@@ -72,21 +82,22 @@ class Scheduler(Process):
                 autoescape=select_autoescape(),
             )
 
-            files = ["scheduler.sh", "scheduler.sub", "start_scheduler.py"]
+            files = ["scheduler.sh", "scheduler.sub", "start_scheduler.py", "job_submit.sh"]
 
             for f in files:
                 tmpl = env.get_template(f)
-                with open(f) as dest:
-                    dest.write(tmpdirname + tmpl.render())
+                with open(tmpdirname + "/" + f, "w") as dest:
+                    dest.write(tmpl.render())
 
-            cmd = (
-                "source ~/.htc.rc; cd {tmpdirname}; condor_submit -spool scheduler.sub"
-            )
-
-            cmd_out = check_output(cmd, stderr=STDOUT, shell=True)
+            cmd = "source ~/htc.rc; cd {}; condor_submit -spool scheduler.sub".format(tmpdirname)
 
             try:
-                self.cluster_id = cmd_out.split("cluster ")[1].strip(".")
+                cmd_out = check_output(cmd, stderr=STDOUT, shell=True)
+            except Exception as ex:
+                raise ex
+
+            try:
+                self.cluster_id = str(cmd_out).split("cluster ")[1].strip(".\\n'")
             except:
                 raise Exception("Failed to submit job for scheduler: %s" % cmd_out)
 
@@ -96,7 +107,7 @@ class Scheduler(Process):
         job_status = 1
         while job_status == 1:
             time.sleep(30)
-            cmd = "source ~/.htc.rc; condor_q {self.cluster_id}.0 -json"
+            cmd = "source ~/htc.rc; condor_q {}.0 -json".format(self.cluster_id)
 
             cmd_out = check_output(cmd, stderr=STDOUT, shell=True)
 
@@ -110,7 +121,7 @@ class Scheduler(Process):
                 # logger.info("Job {cluster_id}.0 still idle")
                 continue
             elif job_status != 2:
-                raise Exception("Scheduler job in error {job_status}")
+                raise Exception("Scheduler job in error {}".format(job_status))
 
             startd_ip_classAd = classAd[0].get("StartdIpAddr")
             if not startd_ip_classAd:
@@ -120,59 +131,45 @@ class Scheduler(Process):
 
         import asyncssh  # import now to avoid adding to module startup time
 
-        self.connection = await asyncssh.connect("90.147.75.109")
+        self.connection = await asyncssh.connect("90.147.75.109", username="root", known_hosts=None)
         await self.connection.forward_local_port("", 8989, startd_ip, 8989)
 
-        self.connection_dash = await asyncssh.connect("90.147.75.109")
+        self.connection_dash = await asyncssh.connect("90.147.75.109", username="root", known_hosts=None)
         await self.connection.forward_local_port("", 8787, startd_ip, 8787)
 
         self.address = "localhost:8989"
         await super().start()
 
     async def close(self):
-        cmd = "source ~/.htc.rc; condor_rm {self.cluster_id}.0"
+        cmd = "source ~/htc.rc; condor_rm {}.0".format(self.cluster_id)
 
-        cmd_out = check_output(cmd, stderr=STDOUT, shell=True)
+        try:
+            cmd_out = check_output(cmd, stderr=STDOUT, shell=True)
+        except Exception as ex:
+            raise ex
 
-        if cmd_out != "Job {self.cluster_id}.0 marked for removal":
+        if cmd_out != "Job {}.0 marked for removal".format(self.cluster_id):
             raise Exception(
-                "Failed to hold job {self.cluster_id} for scheduler: %s" % cmd_out
+                "Failed to hold job for scheduler: %s" % cmd_out
             )
 
         await super().close()
 
 
-class RemoteHTCondorCluster(HTCondorCluster):
-    def __init__(
-        self,
-        n_workers=0,
-        job_cls: Job = None,
-        # Cluster keywords
-        loop=None,
-        security=None,
-        silence_logs="error",
-        name=None,
-        asynchronous=False,
-        # Scheduler-only keywords
-        dashboard_address=None,
-        host=None,
-        scheduler_options=None,
-        # Options for both scheduler and workers
-        interface=None,
-        protocol="tcp://",
-        # Job keywords
-        config_name=None,
-        **job_kwargs,
-    ):
-        scheduler = {
-            "cls": Scheduler,  # Use local scheduler for now
-            "options": scheduler_options,
+def CreateRemoteHTCondor():
+    # workers = {
+    #     0:{
+    #         "cls": Job,
+    #         "options": {
+    #             "cores": 1,
+    #             "memory": "3GB",
+    #             "disk": "1GB"
+    #         }
+    #     }
+    #     }
+    sched = {
+            "cls": Scheduler,
+            "options": {}  # Use local scheduler for now
         }
 
-        super().__init__(
-            scheduler=scheduler,
-        )
-
-
-def CreateRemoteHTCondor():
-    return RemoteHTCondorCluster(dashboard_address="localhost:8787")
+    return SpecCluster({}, sched, name="SSHCluster") 
